@@ -147,7 +147,7 @@ int lastpass_share_user_add(const struct session *session,
 					   "update", "1",
 					   "add", "1",
 					   "notify", "1",
-					   "uid0", share_user->uid,
+					   "username0", share_user->username,
 					   "cgid0", share_user->cgid ? share_user->cgid : "",
 					   "sharekey0", hex_enc_share_key,
 					   "sharename", enc_share_name,
