@@ -26,4 +26,6 @@ int lastpass_share_get_limits(const struct session *session, struct share *share
 int lastpass_share_set_limits(const struct session *session, struct share *share, struct share_user *user, struct share_limit *limit);
 int lastpass_pwchange_start(const struct session *session, const char *username, const char hash[KDF_HEX_LEN], struct pwchange_info *pwchange_info);
 int lastpass_pwchange_complete(const struct session *session, const char *username, const char *enc_username, const char new_hash[KDF_HEX_LEN], int new_iterations, struct pwchange_info *pwchange_info);
+int lastpass_upload(const struct session *session, struct list_head *accounts);
+int lastpass_load_attachment(const struct session *session, const char *shareid, struct attach *attach, char **result);
 #endif
